pub const fn validate(regex: &str)Expand description
Validates the provided regular expression, panicking on errors. This is a shortcut for
try_validate().unwrap().
Panics
Panics if the provided regex is not a valid regular expression.
pub const fn validate(regex: &str)Validates the provided regular expression, panicking on errors. This is a shortcut for
try_validate().unwrap().
Panics if the provided regex is not a valid regular expression.