Stack

Struct Stack 

pub struct Stack<T, const N: usize = 128> { /* private fields */ }
Bounded-capacity stack with const fn operations. Used to store syntax spans via Syntax type alias.

Implementations

Source

impl<T, const N: usize> Stack<T, N>

pub const fn as_slice(&self) -> &[T]

Returns the underlying slice of elements.

pub fn iter( &self, ) -> impl ExactSizeIterator<Item = &T> + DoubleEndedIterator + '_

Iterates over elements in this stack in the order of their insertion.

pub const fn is_empty(&self) -> bool

Checks whether the stack is empty (has 0 elements).

pub const fn len(&self) -> usize

Returns the number of elements in the stack.