Function try_validate
Source pub const fn try_validate(regex: &str) -> Result<(), Error>
Tries to validate the provided regular expression with the default options.
Errors
Returns an error if the provided regex is not a valid regular expression.